@@ -28,19 +28,19 @@
 
 #include <ctype.h>
 
-#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-class-gen-plugin.ui"
+#define BUILDER_FILE PACKAGE_DATA_DIR "/glade/anjuta-class-gen-plugin.ui"
 
-#define CC_HEADER_TEMPLATE PACKAGE_DATA_DIR"/class-templates/cc-header.tpl"
-#define CC_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/cc-source.tpl"
+#define CC_HEADER_TEMPLATE PACKAGE_DATA_DIR "/class-templates/cc-header.tpl"
+#define CC_SOURCE_TEMPLATE PACKAGE_DATA_DIR "/class-templates/cc-source.tpl"
 
-#define GO_HEADER_TEMPLATE PACKAGE_DATA_DIR"/class-templates/go-header.tpl"
-#define GO_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/go-source.tpl"
+#define GO_HEADER_TEMPLATE PACKAGE_DATA_DIR "/class-templates/go-header.tpl"
+#define GO_SOURCE_TEMPLATE PACKAGE_DATA_DIR "/class-templates/go-source.tpl"
 
-#define PY_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/py-source.tpl"
+#define PY_SOURCE_TEMPLATE PACKAGE_DATA_DIR "/class-templates/py-source.tpl"
 
-#define JS_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/js-source.tpl"
+#define JS_SOURCE_TEMPLATE PACKAGE_DATA_DIR "/class-templates/js-source.tpl"
 
-#define VALA_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/vala-source.tpl"
+#define VALA_SOURCE_TEMPLATE PACKAGE_DATA_DIR "/class-templates/vala-source.tpl"
 
 typedef struct _CgWindowPrivate CgWindowPrivate;
 struct _CgWindowPrivate
@@ -219,7 +219,26 @@ cg_window_fetch_string (CgWindow *window,
 	if (GTK_IS_ENTRY (widget))
 		return g_strdup (gtk_entry_get_text(GTK_ENTRY(widget)));
 	else if (GTK_IS_COMBO_BOX (widget))
-		return gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(widget));
+	{
+ 		GtkTreeIter iter;
+		
+		if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter))
+		{
+      		GtkTreeModel *model;
+			gchar *text;
+
+			model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+			g_return_val_if_fail (GTK_IS_LIST_STORE (model), NULL);
+			
+			gtk_tree_model_get (model, &iter, 0, &text, -1);
+			
+			return text;
+		}
+		else
+		{
+			return NULL;
+		}
+	}
 	else
 		return NULL;
 }
@@ -1268,6 +1287,7 @@ cg_window_create_value_heap (CgWindow *window)
 	static const gchar *LICENSES[] = {
 		"GPL",
 		"LGPL",
+		"BSD",
 		"NONE"
 	};
 
@@ -1458,7 +1478,7 @@ cg_window_create_value_heap (CgWindow *window)
 	npw_value_set_value(value, LICENSES[license_index],
 	                         NPW_VALID_VALUE);
 
-	header_file = g_path_get_basename (cg_window_get_header_file (window));
+	header_file = cg_window_get_header_file (window) != NULL ? g_path_get_basename (cg_window_get_header_file (window)) : NULL;
 	source_file = g_path_get_basename (cg_window_get_source_file (window));
 	
 	value = npw_value_heap_find_value (values, "HeaderFile");
@@ -1492,11 +1512,11 @@ cg_window_get_header_template (CgWindow *window)
 	case 1:
 		return GO_HEADER_TEMPLATE;
 	case 2: /* Python */
-		return PY_SOURCE_TEMPLATE;
+		return NULL;
 	case 3: /* JavaScript */
-		return JS_SOURCE_TEMPLATE;
+		return NULL;
 	case 4: /* Vala */
-		return VALA_SOURCE_TEMPLATE;
+		return NULL;
 	default:
 		g_assert_not_reached ();
 		return NULL;
@@ -1513,7 +1533,7 @@ cg_window_get_header_file(CgWindow *window)
 	entry = GTK_ENTRY (gtk_builder_get_object (priv->bxml, "header_file"));
 	
 	g_return_val_if_fail (GTK_IS_ENTRY (entry), NULL);
-	return gtk_entry_get_text (entry);
+	return gtk_widget_get_sensitive (GTK_WIDGET (entry)) == TRUE ? gtk_entry_get_text (entry) : NULL;
 }
 
 const gchar *
